@@ -38,7 +38,7 @@ use crate::interface::common::{self, Code, Id, Ptr};
 /// assert_eq!(result, expected);
 /// ```
 ///
-/// For further examples see [here](https://github.com/sdsl-rs/sdsl-rs/blob/master/examples/src/select_support_mcl.rs).
+/// For further examples see [here](https://github.com/sdsl-rs/sdsl-rs/blob/master/examples/src/select_supports/select_support_mcl.rs).
 ///
 /// # References
 /// - David Clark:
@@ -49,7 +49,7 @@ pub struct SelectSupportMcl<'a, BitPattern: common::bit_patterns::BitPattern> {
     // Dummy field so BitPattern is used, always None.
     _bp: Option<BitPattern>,
     // Dummy field to retain reference to bit vector.
-    _bit_vector: Option<&'a super::bit_vector::BitVector>,
+    _bit_vector: Option<&'a super::bit_vectors::bit_vector::BitVector>,
     ptr: common::VoidPtr,
     interface: Interface,
 }
@@ -58,7 +58,7 @@ impl<'a, BitPattern: common::bit_patterns::BitPattern> SelectSupportMcl<'a, BitP
     /// Construct a new select support structure.
     /// # Arguments
     /// * `bit_vector` - Bit vector.
-    pub fn new(bit_vector: &'a super::bit_vector::BitVector) -> Result<Self> {
+    pub fn new(bit_vector: &'a super::bit_vectors::bit_vector::BitVector) -> Result<Self> {
         let id = Self::id()?;
         let interface = Interface::new(&id)?;
         let ptr = (interface.create)(*bit_vector.ptr());
